pub struct ExclusiveLockedSharedMemoryBlock<'a>(/* private fields */);Trait Implementations
Sourcetype ConcreteDevice = VulkanGfx
type ConcreteDevice = VulkanGfx
A concrete type of the parent device object.
Sourcefn device(&self) -> &Self::ConcreteDevice
fn device(&self) -> &Self::ConcreteDevice
Retrieve a reference to a device object that creates this object
Sourcefn device_handle(&self) -> VkDevice
fn device_handle(&self) -> VkDevice
Retrieve a reference to a device handle that creates this objecs
fn device_transparent_ref<'a>(&'a self) -> VkHandleRef<'a, VkDevice>
Sourcefn commitment_bytes(&self) -> u64
fn commitment_bytes(&self) -> u64
Query the current commitment for a
DeviceMemorySourceunsafe fn map_raw(
&mut self,
range: Range<u64>,
) -> Result<*mut c_void, ResultCode>
unsafe fn map_raw( &mut self, range: Range<u64>, ) -> Result<*mut c_void, ResultCode>
Map a memory object into application address space Read more
Sourcefn map<'a>(
&'a mut self,
range: Range<usize>,
) -> Result<MappedMemory<'a, Self>, ResultCode>
fn map<'a>( &'a mut self, range: Range<usize>, ) -> Result<MappedMemory<'a, Self>, ResultCode>
Map a memory object into application address space Read more
type Handle = VkDeviceMemory
Sourcefn native_ptr(&self) -> Self::Handle
fn native_ptr(&self) -> Self::Handle
Retrieve an underlying handle
fn as_transparent_ref<'a>(&'a self) -> VkHandleRef<'a, Self::Handle>
Sourcefn native_ptr_mut(&mut self) -> Self::Handle
fn native_ptr_mut(&mut self) -> Self::Handle
Retrieve an underlying mutable handle
fn as_transparent_ref_mut<'a>(&'a mut self) -> VkHandleRefMut<'a, Self::Handle>